# Bayesian Symbolic Regression

## Introduction

Symbolic regression (SR) refers to a class of algorithms that search for interpretable symbolic expressions which
capture relationships within data. More specifically, SR attempts to find compositions of simple functions that 
accurately map independent variables to dependent variables within a given dataset. Bayesian Symbolic Regression (BSR),
proposed by [Jin et. al (2019)](https://arxiv.org/abs/1910.08892), is a specific SR method that uses a Bayesian 
framework to search for concise and interpretable expressions.

AutoRA provides an adapted version of BSR for automating the discovery of interpretable models of human information 
processing.

## References

Jin et al., Bayesian Symbolic Regression. (2020).
